#
# spec file for package osmo-bsc
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2017-2021, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           osmo-bsc
Version:        1.8.0
Release:        2.3
Summary:        OsmoBSC: Osmocom's Base Station Controller for 2G CS mobile networks
License:        AGPL-3.0-or-later AND GPL-2.0-or-later
Group:          Hardware/Mobile
URL:            https://osmocom.org/projects/openbsc/wiki/Osmo-bsc
Source:         %{name}-%{version}.tar.xz
#Patch0:         0001-handorer.h-Fix-compilation-with-gcc-10.patch
Patch1:         harden_osmo-bsc.service.patch
BuildRequires:  automake >= 1.9
BuildRequires:  libtool >= 2
BuildRequires:  pkgconfig >= 0.20
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(libcrypto) >= 0.9.5
BuildRequires:  pkgconfig(libosmo-mgcp-client) >= 1.9.0
BuildRequires:  pkgconfig(libosmo-netif) >= 0.6.0
BuildRequires:  pkgconfig(libosmo-sccp) >= 0.10.0
BuildRequires:  pkgconfig(libosmo-sigtran) >= 1.5.0
BuildRequires:  pkgconfig(libosmoabis) >= 1.2.0
BuildRequires:  pkgconfig(libosmocore) >= 1.6.0
BuildRequires:  pkgconfig(libosmoctrl) >= 1.6.0
BuildRequires:  pkgconfig(libosmogb) >= 1.6.0
BuildRequires:  pkgconfig(libosmogsm) >= 1.6.0
BuildRequires:  pkgconfig(libosmovty) >= 1.6.0
BuildRequires:  pkgconfig(talloc)
%{?systemd_requires}

%description
OsmoBSC: Osmocom's Base Station Controller for 2G circuit-switched mobile networks.

%package abisip-find
Summary:        CLI utility to find ip.access compatible BTS
License:        GPL-2.0-or-later
Group:          Productivity/Telephony/Utilities

%description abisip-find
Command line utility to find ip.access compatible BTS.

%package ipaccess-utils
Summary:        Command line utilities for ip.access nanoBTS
License:        GPL-2.0-or-later
Group:          Productivity/Telephony/Utilities

%description ipaccess-utils
This package contains utilities that are specific for nanoBTS when being
used together with OpenBSC. It contains mainly two tools: ipaccess-config
and ipaccess-proxy.

%package bs11-utils
Summary:        Command line utilities for Siemens BS-11 BTS
License:        GPL-2.0-or-later
Group:          Productivity/Telephony/Utilities
Conflicts:      openbsc-bs11-utils

%description bs11-utils
There is a tool in this package for configuring the Siemens BS-11 BTS.
Additionally, it contains one tool for making use of an ISDN-card and the
public telephone network as frequency standard for the E1 line.

%package meas-utils
Summary:        Command line utilities for OsmoBSC's measurement reports
License:        GPL-2.0-or-later
Group:          Productivity/Telephony/Utilities

%description meas-utils
This package contains utilities for handling OsmoBSC's measurement reports
 * meas_json to convert measurement feed into a JSON feed

%prep
%setup -q
#%%patch -P 0 -p1
%patch -P 1 -p1

%build
echo "%{version}" >.tarball-version
autoreconf -fi
%configure \
  --docdir=%{_docdir}/%{name} \
  --with-systemdsystemunitdir=%{_unitdir}
make %{?_smp_mflags}

%install
%make_install
install -d %{buildroot}/%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}/%{_sbindir}/rc%{name}

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%pre
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service

%check
make %{?_smp_mflags} check || (find . -name testsuite.log -exec cat {} +)

%files
%license COPYING
%doc AUTHORS README
%{_bindir}/osmo-bsc
%dir %{_docdir}/%{name}/examples
%dir %{_docdir}/%{name}/examples/osmo-bsc
%{_docdir}/%{name}/examples/osmo-bsc/
%dir %{_sysconfdir}/osmocom
%config(noreplace) %{_sysconfdir}/osmocom/osmo-bsc.cfg
%{_unitdir}/%{name}.service
%{_sbindir}/rc%{name}

%files abisip-find
%{_bindir}/abisip-find

%files ipaccess-utils
%{_bindir}/ipaccess-config
%{_bindir}/ipaccess-proxy

%files bs11-utils
%{_bindir}/bs11_config
%{_bindir}/isdnsync

%files meas-utils
%{_bindir}/meas_json

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Fri Nov 19 2021 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 1.8.0
  * https://git.osmocom.org/osmo-bsc/plain/debian/changelog?h=1.8.0
- Drop patch:
  * 0001-handorer.h-Fix-compilation-with-gcc-10.patch
* Wed Oct 13 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_osmo-bsc.service.patch
* Thu Jun 11 2020 Martin Hauke <mardnh@gmx.de>
- Add patch to fix gcc10 compilation errors (boo#1160244)
  * 0001-handorer.h-Fix-compilation-with-gcc-10.patch
* Sat Jan  4 2020 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 1.6.0
  * bsc: Send MS Power Control msg upon max MS power change
  * osmo_bsc_main.c: verify the physical channel mapping at startup
  * SMSCB: Send ETWS Primary Notifiation via RSL to BTS
  * SMSCB: Send ETWS primary warning message via all dedicated channels
  * Cell Broadcast: CBSP and CBCH scheduling support
  * add vty 'no neighbors' to remove all HO targets
- Update to new upstream release 1.5.0
  * vty: adjust config name for unit-id
  * Introduce msc_is_{sccplite,aoip}() helpers
  * Move msc related code from gsm_data to bsc_msc
  * Move LCLS references from gsm_data to osmo_bsc_lcls
  * bsc_vty: add features to disable specific lchans via vty
  * Implement CSFB "Fast Return" Handling at RR RELEASE
  * bsc_vty: add vty command to display all lchans
* Sat Jul 27 2019 Martin Hauke <mardnh@gmx.de>
- Disable LTO for now since it breaks compilation of the tests
  See: https://osmocom.org/issues/4113
* Wed Mar  6 2019 Martin Hauke <mardnh@gmx.de>
- Add conflicts to openbsc-bs11-utils
* Wed Jan 30 2019 mardnh@gmx.de
- Update to new upstream release 1.4.0
  * inter-BSC hand-over support (AoIP and SCCPlite)
  * large refactoring: use FSMs for lchans; timeslots;
    MGCP endpoints; ...
  * Implement RR Classmark Enquiry in case
  * various LCLS related fixes
  * various codec / channel type related fixes during ASSIGNMENT
  * interop tested against 3rd party MSCs for both AoIP and SCCPlite
  * Full changelogs since 1.1.2:
    http://git.osmocom.org/osmo-bsc/plain/debian/changelog?h=1.4.0
    http://git.osmocom.org/osmo-bsc/plain/debian/changelog?h=1.3.0
- Remove patches:
  * osmo-bsc-fix-includes.patch
* Sat Mar 17 2018 mardnh@gmx.de
- Show testsuite.log when tests are failing
- Create subpackages for
  * abisip-find
  * ipaccess-utils
  * bs11-utils
* Thu Dec 28 2017 mardnh@gmx.de
- Add patch:
  * osmo-bsc-fix-includes.patch
* Wed Dec 27 2017 mardnh@gmx.de
- Initial package, version 1.1.2
